# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FunctionRpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from .identity import ClaimsIdentityRpc_pb2 as identity_dot_ClaimsIdentityRpc__pb2
from .shared import NullableTypes_pb2 as shared_dot_NullableTypes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x46unctionRpc.proto\x12\x19\x41zureFunctionsRpcMessages\x1a\x1egoogle/protobuf/duration.proto\x1a identity/ClaimsIdentityRpc.proto\x1a\x1ashared/NullableTypes.proto\"\x8c\x11\n\x10StreamingMessage\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12>\n\x0cstart_stream\x18\x14 \x01(\x0b\x32&.AzureFunctionsRpcMessages.StartStreamH\x00\x12K\n\x13worker_init_request\x18\x11 \x01(\x0b\x32,.AzureFunctionsRpcMessages.WorkerInitRequestH\x00\x12M\n\x14worker_init_response\x18\x10 \x01(\x0b\x32-.AzureFunctionsRpcMessages.WorkerInitResponseH\x00\x12\x46\n\x10worker_heartbeat\x18\x0f \x01(\x0b\x32*.AzureFunctionsRpcMessages.WorkerHeartbeatH\x00\x12\x46\n\x10worker_terminate\x18\x0e \x01(\x0b\x32*.AzureFunctionsRpcMessages.WorkerTerminateH\x00\x12O\n\x15worker_status_request\x18\x0c \x01(\x0b\x32..AzureFunctionsRpcMessages.WorkerStatusRequestH\x00\x12Q\n\x16worker_status_response\x18\r \x01(\x0b\x32/.AzureFunctionsRpcMessages.WorkerStatusResponseH\x00\x12V\n\x19\x66ile_change_event_request\x18\x06 \x01(\x0b\x32\x31.AzureFunctionsRpcMessages.FileChangeEventRequestH\x00\x12Q\n\x16worker_action_response\x18\x07 \x01(\x0b\x32/.AzureFunctionsRpcMessages.WorkerActionResponseH\x00\x12O\n\x15\x66unction_load_request\x18\x08 \x01(\x0b\x32..AzureFunctionsRpcMessages.FunctionLoadRequestH\x00\x12Q\n\x16\x66unction_load_response\x18\t \x01(\x0b\x32/.AzureFunctionsRpcMessages.FunctionLoadResponseH\x00\x12J\n\x12invocation_request\x18\x04 \x01(\x0b\x32,.AzureFunctionsRpcMessages.InvocationRequestH\x00\x12L\n\x13invocation_response\x18\x05 \x01(\x0b\x32-.AzureFunctionsRpcMessages.InvocationResponseH\x00\x12H\n\x11invocation_cancel\x18\x15 \x01(\x0b\x32+.AzureFunctionsRpcMessages.InvocationCancelH\x00\x12\x34\n\x07rpc_log\x18\x02 \x01(\x0b\x32!.AzureFunctionsRpcMessages.RpcLogH\x00\x12j\n#function_environment_reload_request\x18\x19 \x01(\x0b\x32;.AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequestH\x00\x12l\n$function_environment_reload_response\x18\x1a \x01(\x0b\x32<.AzureFunctionsRpcMessages.FunctionEnvironmentReloadResponseH\x00\x12m\n%close_shared_memory_resources_request\x18\x1b \x01(\x0b\x32<.AzureFunctionsRpcMessages.CloseSharedMemoryResourcesRequestH\x00\x12o\n&close_shared_memory_resources_response\x18\x1c \x01(\x0b\x32=.AzureFunctionsRpcMessages.CloseSharedMemoryResourcesResponseH\x00\x12Y\n\x1a\x66unctions_metadata_request\x18\x1d \x01(\x0b\x32\x33.AzureFunctionsRpcMessages.FunctionsMetadataRequestH\x00\x12Y\n\x1a\x66unction_metadata_response\x18\x1e \x01(\x0b\x32\x33.AzureFunctionsRpcMessages.FunctionMetadataResponseH\x00\x12\x64\n function_load_request_collection\x18\x1f \x01(\x0b\x32\x38.AzureFunctionsRpcMessages.FunctionLoadRequestCollectionH\x00\x12\x66\n!function_load_response_collection\x18  \x01(\x0b\x32\x39.AzureFunctionsRpcMessages.FunctionLoadResponseCollectionH\x00\x12O\n\x15worker_warmup_request\x18! \x01(\x0b\x32..AzureFunctionsRpcMessages.WorkerWarmupRequestH\x00\x12Q\n\x16worker_warmup_response\x18\" \x01(\x0b\x32/.AzureFunctionsRpcMessages.WorkerWarmupResponseH\x00\x42\t\n\x07\x63ontent\" \n\x0bStartStream\x12\x11\n\tworker_id\x18\x02 \x01(\t\"\xa6\x03\n\x11WorkerInitRequest\x12\x14\n\x0chost_version\x18\x01 \x01(\t\x12T\n\x0c\x63\x61pabilities\x18\x02 \x03(\x0b\x32>.AzureFunctionsRpcMessages.WorkerInitRequest.CapabilitiesEntry\x12W\n\x0elog_categories\x18\x03 \x03(\x0b\x32?.AzureFunctionsRpcMessages.WorkerInitRequest.LogCategoriesEntry\x12\x18\n\x10worker_directory\x18\x04 \x01(\t\x12\x1e\n\x16\x66unction_app_directory\x18\x05 \x01(\t\x1a\x33\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a]\n\x12LogCategoriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0e\x32\'.AzureFunctionsRpcMessages.RpcLog.Level:\x02\x38\x01\"\xb5\x02\n\x12WorkerInitResponse\x12\x16\n\x0eworker_version\x18\x01 \x01(\t\x12U\n\x0c\x63\x61pabilities\x18\x02 \x03(\x0b\x32?.AzureFunctionsRpcMessages.WorkerInitResponse.CapabilitiesEntry\x12\x37\n\x06result\x18\x03 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\x12\x42\n\x0fworker_metadata\x18\x04 \x01(\x0b\x32).AzureFunctionsRpcMessages.WorkerMetadata\x1a\x33\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x02\n\x0eWorkerMetadata\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\x12\x17\n\x0fruntime_version\x18\x02 \x01(\t\x12\x16\n\x0eworker_version\x18\x03 \x01(\t\x12\x16\n\x0eworker_bitness\x18\x04 \x01(\t\x12Z\n\x11\x63ustom_properties\x18\x05 \x03(\x0b\x32?.AzureFunctionsRpcMessages.WorkerMetadata.CustomPropertiesEntry\x1a\x37\n\x15\x43ustomPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfe\x01\n\x0cStatusResult\x12>\n\x06status\x18\x04 \x01(\x0e\x32..AzureFunctionsRpcMessages.StatusResult.Status\x12\x0e\n\x06result\x18\x01 \x01(\t\x12:\n\texception\x18\x02 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.RpcException\x12/\n\x04logs\x18\x03 \x03(\x0b\x32!.AzureFunctionsRpcMessages.RpcLog\"1\n\x06Status\x12\x0b\n\x07\x46\x61ilure\x10\x00\x12\x0b\n\x07Success\x10\x01\x12\r\n\tCancelled\x10\x02\"\x11\n\x0fWorkerHeartbeat\"B\n\x0fWorkerTerminate\x12/\n\x0cgrace_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xd1\x01\n\x16\x46ileChangeEventRequest\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.AzureFunctionsRpcMessages.FileChangeEventRequest.Type\x12\x11\n\tfull_path\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"P\n\x04Type\x12\x0b\n\x07Unknown\x10\x00\x12\x0b\n\x07\x43reated\x10\x01\x12\x0b\n\x07\x44\x65leted\x10\x02\x12\x0b\n\x07\x43hanged\x10\x04\x12\x0b\n\x07Renamed\x10\x08\x12\x07\n\x03\x41ll\x10\x0f\"\x91\x01\n\x14WorkerActionResponse\x12\x46\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x36.AzureFunctionsRpcMessages.WorkerActionResponse.Action\x12\x0e\n\x06reason\x18\x02 \x01(\t\"!\n\x06\x41\x63tion\x12\x0b\n\x07Restart\x10\x00\x12\n\n\x06Reload\x10\x01\"\x15\n\x13WorkerStatusRequest\"\x16\n\x14WorkerStatusResponse\"\xf5\x01\n FunctionEnvironmentReloadRequest\x12t\n\x15\x65nvironment_variables\x18\x01 \x03(\x0b\x32U.AzureFunctionsRpcMessages.FunctionEnvironmentReloadRequest.EnvironmentVariablesEntry\x12\x1e\n\x16\x66unction_app_directory\x18\x02 \x01(\t\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbb\x02\n!FunctionEnvironmentReloadResponse\x12\x42\n\x0fworker_metadata\x18\x01 \x01(\x0b\x32).AzureFunctionsRpcMessages.WorkerMetadata\x12\x64\n\x0c\x63\x61pabilities\x18\x02 \x03(\x0b\x32N.AzureFunctionsRpcMessages.FunctionEnvironmentReloadResponse.CapabilitiesEntry\x12\x37\n\x06result\x18\x03 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\x1a\x33\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n!CloseSharedMemoryResourcesRequest\x12\x11\n\tmap_names\x18\x01 \x03(\t\"\xcb\x01\n\"CloseSharedMemoryResourcesResponse\x12m\n\x11\x63lose_map_results\x18\x01 \x03(\x0b\x32R.AzureFunctionsRpcMessages.CloseSharedMemoryResourcesResponse.CloseMapResultsEntry\x1a\x36\n\x14\x43loseMapResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"o\n\x1d\x46unctionLoadRequestCollection\x12N\n\x16\x66unction_load_requests\x18\x01 \x03(\x0b\x32..AzureFunctionsRpcMessages.FunctionLoadRequest\"r\n\x1e\x46unctionLoadResponseCollection\x12P\n\x17\x66unction_load_responses\x18\x01 \x03(\x0b\x32/.AzureFunctionsRpcMessages.FunctionLoadResponse\"\x90\x01\n\x13\x46unctionLoadRequest\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32..AzureFunctionsRpcMessages.RpcFunctionMetadata\x12\"\n\x1amanaged_dependency_enabled\x18\x03 \x01(\x08\"\x86\x01\n\x14\x46unctionLoadResponse\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12\x37\n\x06result\x18\x02 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\x12 \n\x18is_dependency_downloaded\x18\x03 \x01(\x08\"\xff\x04\n\x13RpcFunctionMetadata\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x13\n\x0bscript_file\x18\x02 \x01(\t\x12\x13\n\x0b\x65ntry_point\x18\x03 \x01(\t\x12N\n\x08\x62indings\x18\x06 \x03(\x0b\x32<.AzureFunctionsRpcMessages.RpcFunctionMetadata.BindingsEntry\x12\x10\n\x08is_proxy\x18\x07 \x01(\x08\x12\x37\n\x06status\x18\x08 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\x12\x10\n\x08language\x18\t \x01(\t\x12\x14\n\x0craw_bindings\x18\n \x03(\t\x12\x13\n\x0b\x66unction_id\x18\r \x01(\t\x12\"\n\x1amanaged_dependency_enabled\x18\x0e \x01(\x08\x12\x41\n\rretry_options\x18\x0f \x01(\x0b\x32*.AzureFunctionsRpcMessages.RpcRetryOptions\x12R\n\nproperties\x18\x10 \x03(\x0b\x32>.AzureFunctionsRpcMessages.RpcFunctionMetadata.PropertiesEntry\x1aW\n\rBindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.AzureFunctionsRpcMessages.BindingInfo:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x18\x46unctionsMetadataRequest\x12\x1e\n\x16\x66unction_app_directory\x18\x01 \x01(\t\"\xcd\x01\n\x18\x46unctionMetadataResponse\x12Q\n\x19\x66unction_metadata_results\x18\x01 \x03(\x0b\x32..AzureFunctionsRpcMessages.RpcFunctionMetadata\x12\x37\n\x06result\x18\x02 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\x12%\n\x1duse_default_metadata_indexing\x18\x03 \x01(\x08\"\xbe\x03\n\x11InvocationRequest\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66unction_id\x18\x02 \x01(\t\x12?\n\ninput_data\x18\x03 \x03(\x0b\x32+.AzureFunctionsRpcMessages.ParameterBinding\x12[\n\x10trigger_metadata\x18\x04 \x03(\x0b\x32\x41.AzureFunctionsRpcMessages.InvocationRequest.TriggerMetadataEntry\x12\x41\n\rtrace_context\x18\x05 \x01(\x0b\x32*.AzureFunctionsRpcMessages.RpcTraceContext\x12>\n\rretry_context\x18\x06 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.RetryContext\x1a\\\n\x14TriggerMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData:\x02\x38\x01\"\xbf\x01\n\x0fRpcTraceContext\x12\x14\n\x0ctrace_parent\x18\x01 \x01(\t\x12\x13\n\x0btrace_state\x18\x02 \x01(\t\x12N\n\nattributes\x18\x03 \x03(\x0b\x32:.AzureFunctionsRpcMessages.RpcTraceContext.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x0cRetryContext\x12\x13\n\x0bretry_count\x18\x01 \x01(\x05\x12\x17\n\x0fmax_retry_count\x18\x02 \x01(\x05\x12:\n\texception\x18\x03 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.RpcException\"Z\n\x10InvocationCancel\x12\x15\n\rinvocation_id\x18\x02 \x01(\t\x12/\n\x0cgrace_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xe2\x01\n\x12InvocationResponse\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12@\n\x0boutput_data\x18\x02 \x03(\x0b\x32+.AzureFunctionsRpcMessages.ParameterBinding\x12:\n\x0creturn_value\x18\x04 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData\x12\x37\n\x06result\x18\x03 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\"/\n\x13WorkerWarmupRequest\x12\x18\n\x10worker_directory\x18\x01 \x01(\t\"O\n\x14WorkerWarmupResponse\x12\x37\n\x06result\x18\x01 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.StatusResult\"\xfe\x04\n\tTypedData\x12\x10\n\x06string\x18\x01 \x01(\tH\x00\x12\x0e\n\x04json\x18\x02 \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\x03 \x01(\x0cH\x00\x12\x10\n\x06stream\x18\x04 \x01(\x0cH\x00\x12\x32\n\x04http\x18\x05 \x01(\x0b\x32\".AzureFunctionsRpcMessages.RpcHttpH\x00\x12\r\n\x03int\x18\x06 \x01(\x12H\x00\x12\x10\n\x06\x64ouble\x18\x07 \x01(\x01H\x00\x12\x46\n\x10\x63ollection_bytes\x18\x08 \x01(\x0b\x32*.AzureFunctionsRpcMessages.CollectionBytesH\x00\x12H\n\x11\x63ollection_string\x18\t \x01(\x0b\x32+.AzureFunctionsRpcMessages.CollectionStringH\x00\x12H\n\x11\x63ollection_double\x18\n \x01(\x0b\x32+.AzureFunctionsRpcMessages.CollectionDoubleH\x00\x12H\n\x11\x63ollection_sint64\x18\x0b \x01(\x0b\x32+.AzureFunctionsRpcMessages.CollectionSInt64H\x00\x12I\n\x12model_binding_data\x18\x0c \x01(\x0b\x32+.AzureFunctionsRpcMessages.ModelBindingDataH\x00\x12^\n\x1d\x63ollection_model_binding_data\x18\r \x01(\x0b\x32\x35.AzureFunctionsRpcMessages.CollectionModelBindingDataH\x00\x42\x06\n\x04\x64\x61ta\"t\n\x0fRpcSharedMemory\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x12\x34\n\x04type\x18\x04 \x01(\x0e\x32&.AzureFunctionsRpcMessages.RpcDataType\"\"\n\x10\x43ollectionString\x12\x0e\n\x06string\x18\x01 \x03(\t\" \n\x0f\x43ollectionBytes\x12\r\n\x05\x62ytes\x18\x01 \x03(\x0c\"\"\n\x10\x43ollectionDouble\x12\x0e\n\x06\x64ouble\x18\x01 \x03(\x01\"\"\n\x10\x43ollectionSInt64\x12\x0e\n\x06sint64\x18\x01 \x03(\x12\"\xab\x01\n\x10ParameterBinding\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedDataH\x00\x12G\n\x11rpc_shared_memory\x18\x03 \x01(\x0b\x32*.AzureFunctionsRpcMessages.RpcSharedMemoryH\x00\x42\n\n\x08rpc_data\"\x8b\x03\n\x0b\x42indingInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x43\n\tdirection\x18\x03 \x01(\x0e\x32\x30.AzureFunctionsRpcMessages.BindingInfo.Direction\x12\x42\n\tdata_type\x18\x04 \x01(\x0e\x32/.AzureFunctionsRpcMessages.BindingInfo.DataType\x12J\n\nproperties\x18\x05 \x03(\x0b\x32\x36.AzureFunctionsRpcMessages.BindingInfo.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\tDirection\x12\x06\n\x02in\x10\x00\x12\x07\n\x03out\x10\x01\x12\t\n\x05inout\x10\x02\"=\n\x08\x44\x61taType\x12\r\n\tundefined\x10\x00\x12\n\n\x06string\x10\x01\x12\n\n\x06\x62inary\x10\x02\x12\n\n\x06stream\x10\x03\"\xe7\x04\n\x06RpcLog\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x36\n\x05level\x18\x03 \x01(\x0e\x32\'.AzureFunctionsRpcMessages.RpcLog.Level\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12:\n\texception\x18\x06 \x01(\x0b\x32\'.AzureFunctionsRpcMessages.RpcException\x12\x12\n\nproperties\x18\x07 \x01(\t\x12\x46\n\x0clog_category\x18\x08 \x01(\x0e\x32\x30.AzureFunctionsRpcMessages.RpcLog.RpcLogCategory\x12K\n\rpropertiesMap\x18\t \x03(\x0b\x32\x34.AzureFunctionsRpcMessages.RpcLog.PropertiesMapEntry\x1aZ\n\x12PropertiesMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData:\x02\x38\x01\"^\n\x05Level\x12\t\n\x05Trace\x10\x00\x12\t\n\x05\x44\x65\x62ug\x10\x01\x12\x0f\n\x0bInformation\x10\x02\x12\x0b\n\x07Warning\x10\x03\x12\t\n\x05\x45rror\x10\x04\x12\x0c\n\x08\x43ritical\x10\x05\x12\x08\n\x04None\x10\x06\"8\n\x0eRpcLogCategory\x12\x08\n\x04User\x10\x00\x12\n\n\x06System\x10\x01\x12\x10\n\x0c\x43ustomMetric\x10\x02\"m\n\x0cRpcException\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x13\n\x0bstack_trace\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x19\n\x11is_user_exception\x18\x04 \x01(\x08\x12\x0c\n\x04type\x18\x05 \x01(\t\"\xf7\x02\n\rRpcHttpCookie\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x1f\n\x06\x64omain\x18\x03 \x01(\x0b\x32\x0f.NullableString\x12\x1d\n\x04path\x18\x04 \x01(\x0b\x32\x0f.NullableString\x12#\n\x07\x65xpires\x18\x05 \x01(\x0b\x32\x12.NullableTimestamp\x12\x1d\n\x06secure\x18\x06 \x01(\x0b\x32\r.NullableBool\x12 \n\thttp_only\x18\x07 \x01(\x0b\x32\r.NullableBool\x12\x44\n\tsame_site\x18\x08 \x01(\x0e\x32\x31.AzureFunctionsRpcMessages.RpcHttpCookie.SameSite\x12 \n\x07max_age\x18\t \x01(\x0b\x32\x0f.NullableDouble\";\n\x08SameSite\x12\x08\n\x04None\x10\x00\x12\x07\n\x03Lax\x10\x01\x12\n\n\x06Strict\x10\x02\x12\x10\n\x0c\x45xplicitNone\x10\x03\"\xc5\x08\n\x07RpcHttp\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12@\n\x07headers\x18\x03 \x03(\x0b\x32/.AzureFunctionsRpcMessages.RpcHttp.HeadersEntry\x12\x32\n\x04\x62ody\x18\x04 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData\x12>\n\x06params\x18\n \x03(\x0b\x32..AzureFunctionsRpcMessages.RpcHttp.ParamsEntry\x12\x13\n\x0bstatus_code\x18\x0c \x01(\t\x12<\n\x05query\x18\x0f \x03(\x0b\x32-.AzureFunctionsRpcMessages.RpcHttp.QueryEntry\x12\"\n\x1a\x65nable_content_negotiation\x18\x10 \x01(\x08\x12\x35\n\x07rawBody\x18\x11 \x01(\x0b\x32$.AzureFunctionsRpcMessages.TypedData\x12&\n\nidentities\x18\x12 \x03(\x0b\x32\x12.RpcClaimsIdentity\x12\x39\n\x07\x63ookies\x18\x13 \x03(\x0b\x32(.AzureFunctionsRpcMessages.RpcHttpCookie\x12Q\n\x10nullable_headers\x18\x14 \x03(\x0b\x32\x37.AzureFunctionsRpcMessages.RpcHttp.NullableHeadersEntry\x12O\n\x0fnullable_params\x18\x15 \x03(\x0b\x32\x36.AzureFunctionsRpcMessages.RpcHttp.NullableParamsEntry\x12M\n\x0enullable_query\x18\x16 \x03(\x0b\x32\x35.AzureFunctionsRpcMessages.RpcHttp.NullableQueryEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aG\n\x14NullableHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.NullableString:\x02\x38\x01\x1a\x46\n\x13NullableParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.NullableString:\x02\x38\x01\x1a\x45\n\x12NullableQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.NullableString:\x02\x38\x01\"Z\n\x10ModelBindingData\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\"e\n\x1a\x43ollectionModelBindingData\x12G\n\x12model_binding_data\x18\x01 \x03(\x0b\x32+.AzureFunctionsRpcMessages.ModelBindingData\"\xd4\x02\n\x0fRpcRetryOptions\x12\x17\n\x0fmax_retry_count\x18\x02 \x01(\x05\x12\x31\n\x0e\x64\x65lay_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10minimum_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10maximum_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12P\n\x0eretry_strategy\x18\x06 \x01(\x0e\x32\x38.AzureFunctionsRpcMessages.RpcRetryOptions.RetryStrategy\"9\n\rRetryStrategy\x12\x17\n\x13\x65xponential_backoff\x10\x00\x12\x0f\n\x0b\x66ixed_delay\x10\x01*\xc1\x01\n\x0bRpcDataType\x12\x0b\n\x07unknown\x10\x00\x12\n\n\x06string\x10\x01\x12\x08\n\x04json\x10\x02\x12\t\n\x05\x62ytes\x10\x03\x12\n\n\x06stream\x10\x04\x12\x08\n\x04http\x10\x05\x12\x07\n\x03int\x10\x06\x12\n\n\x06\x64ouble\x10\x07\x12\x14\n\x10\x63ollection_bytes\x10\x08\x12\x15\n\x11\x63ollection_string\x10\t\x12\x15\n\x11\x63ollection_double\x10\n\x12\x15\n\x11\x63ollection_sint64\x10\x0b\x32|\n\x0b\x46unctionRpc\x12m\n\x0b\x45ventStream\x12+.AzureFunctionsRpcMessages.StreamingMessage\x1a+.AzureFunctionsRpcMessages.StreamingMessage\"\x00(\x01\x30\x01\x42\xa5\x01\n*com.microsoft.azure.functions.rpc.messagesB\rFunctionProtoP\x01Z7github.com/Azure/azure-functions-go-worker/internal/rpc\xaa\x02,Microsoft.Azure.WebJobs.Script.Grpc.Messagesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'FunctionRpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.microsoft.azure.functions.rpc.messagesB\rFunctionProtoP\001Z7github.com/Azure/azure-functions-go-worker/internal/rpc\252\002,Microsoft.Azure.WebJobs.Script.Grpc.Messages'
  _WORKERINITREQUEST_CAPABILITIESENTRY._options = None
  _WORKERINITREQUEST_CAPABILITIESENTRY._serialized_options = b'8\001'
  _WORKERINITREQUEST_LOGCATEGORIESENTRY._options = None
  _WORKERINITREQUEST_LOGCATEGORIESENTRY._serialized_options = b'8\001'
  _WORKERINITRESPONSE_CAPABILITIESENTRY._options = None
  _WORKERINITRESPONSE_CAPABILITIESENTRY._serialized_options = b'8\001'
  _WORKERMETADATA_CUSTOMPROPERTIESENTRY._options = None
  _WORKERMETADATA_CUSTOMPROPERTIESENTRY._serialized_options = b'8\001'
  _FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY._options = None
  _FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _FUNCTIONENVIRONMENTRELOADRESPONSE_CAPABILITIESENTRY._options = None
  _FUNCTIONENVIRONMENTRELOADRESPONSE_CAPABILITIESENTRY._serialized_options = b'8\001'
  _CLOSESHAREDMEMORYRESOURCESRESPONSE_CLOSEMAPRESULTSENTRY._options = None
  _CLOSESHAREDMEMORYRESOURCESRESPONSE_CLOSEMAPRESULTSENTRY._serialized_options = b'8\001'
  _RPCFUNCTIONMETADATA_BINDINGSENTRY._options = None
  _RPCFUNCTIONMETADATA_BINDINGSENTRY._serialized_options = b'8\001'
  _RPCFUNCTIONMETADATA_PROPERTIESENTRY._options = None
  _RPCFUNCTIONMETADATA_PROPERTIESENTRY._serialized_options = b'8\001'
  _INVOCATIONREQUEST_TRIGGERMETADATAENTRY._options = None
  _INVOCATIONREQUEST_TRIGGERMETADATAENTRY._serialized_options = b'8\001'
  _RPCTRACECONTEXT_ATTRIBUTESENTRY._options = None
  _RPCTRACECONTEXT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _BINDINGINFO_PROPERTIESENTRY._options = None
  _BINDINGINFO_PROPERTIESENTRY._serialized_options = b'8\001'
  _RPCLOG_PROPERTIESMAPENTRY._options = None
  _RPCLOG_PROPERTIESMAPENTRY._serialized_options = b'8\001'
  _RPCHTTP_HEADERSENTRY._options = None
  _RPCHTTP_HEADERSENTRY._serialized_options = b'8\001'
  _RPCHTTP_PARAMSENTRY._options = None
  _RPCHTTP_PARAMSENTRY._serialized_options = b'8\001'
  _RPCHTTP_QUERYENTRY._options = None
  _RPCHTTP_QUERYENTRY._serialized_options = b'8\001'
  _RPCHTTP_NULLABLEHEADERSENTRY._options = None
  _RPCHTTP_NULLABLEHEADERSENTRY._serialized_options = b'8\001'
  _RPCHTTP_NULLABLEPARAMSENTRY._options = None
  _RPCHTTP_NULLABLEPARAMSENTRY._serialized_options = b'8\001'
  _RPCHTTP_NULLABLEQUERYENTRY._options = None
  _RPCHTTP_NULLABLEQUERYENTRY._serialized_options = b'8\001'
  _globals['_RPCDATATYPE']._serialized_start=11800
  _globals['_RPCDATATYPE']._serialized_end=11993
  _globals['_STREAMINGMESSAGE']._serialized_start=143
  _globals['_STREAMINGMESSAGE']._serialized_end=2331
  _globals['_STARTSTREAM']._serialized_start=2333
  _globals['_STARTSTREAM']._serialized_end=2365
  _globals['_WORKERINITREQUEST']._serialized_start=2368
  _globals['_WORKERINITREQUEST']._serialized_end=2790
  _globals['_WORKERINITREQUEST_CAPABILITIESENTRY']._serialized_start=2644
  _globals['_WORKERINITREQUEST_CAPABILITIESENTRY']._serialized_end=2695
  _globals['_WORKERINITREQUEST_LOGCATEGORIESENTRY']._serialized_start=2697
  _globals['_WORKERINITREQUEST_LOGCATEGORIESENTRY']._serialized_end=2790
  _globals['_WORKERINITRESPONSE']._serialized_start=2793
  _globals['_WORKERINITRESPONSE']._serialized_end=3102
  _globals['_WORKERINITRESPONSE_CAPABILITIESENTRY']._serialized_start=2644
  _globals['_WORKERINITRESPONSE_CAPABILITIESENTRY']._serialized_end=2695
  _globals['_WORKERMETADATA']._serialized_start=3105
  _globals['_WORKERMETADATA']._serialized_end=3365
  _globals['_WORKERMETADATA_CUSTOMPROPERTIESENTRY']._serialized_start=3310
  _globals['_WORKERMETADATA_CUSTOMPROPERTIESENTRY']._serialized_end=3365
  _globals['_STATUSRESULT']._serialized_start=3368
  _globals['_STATUSRESULT']._serialized_end=3622
  _globals['_STATUSRESULT_STATUS']._serialized_start=3573
  _globals['_STATUSRESULT_STATUS']._serialized_end=3622
  _globals['_WORKERHEARTBEAT']._serialized_start=3624
  _globals['_WORKERHEARTBEAT']._serialized_end=3641
  _globals['_WORKERTERMINATE']._serialized_start=3643
  _globals['_WORKERTERMINATE']._serialized_end=3709
  _globals['_FILECHANGEEVENTREQUEST']._serialized_start=3712
  _globals['_FILECHANGEEVENTREQUEST']._serialized_end=3921
  _globals['_FILECHANGEEVENTREQUEST_TYPE']._serialized_start=3841
  _globals['_FILECHANGEEVENTREQUEST_TYPE']._serialized_end=3921
  _globals['_WORKERACTIONRESPONSE']._serialized_start=3924
  _globals['_WORKERACTIONRESPONSE']._serialized_end=4069
  _globals['_WORKERACTIONRESPONSE_ACTION']._serialized_start=4036
  _globals['_WORKERACTIONRESPONSE_ACTION']._serialized_end=4069
  _globals['_WORKERSTATUSREQUEST']._serialized_start=4071
  _globals['_WORKERSTATUSREQUEST']._serialized_end=4092
  _globals['_WORKERSTATUSRESPONSE']._serialized_start=4094
  _globals['_WORKERSTATUSRESPONSE']._serialized_end=4116
  _globals['_FUNCTIONENVIRONMENTRELOADREQUEST']._serialized_start=4119
  _globals['_FUNCTIONENVIRONMENTRELOADREQUEST']._serialized_end=4364
  _globals['_FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY']._serialized_start=4305
  _globals['_FUNCTIONENVIRONMENTRELOADREQUEST_ENVIRONMENTVARIABLESENTRY']._serialized_end=4364
  _globals['_FUNCTIONENVIRONMENTRELOADRESPONSE']._serialized_start=4367
  _globals['_FUNCTIONENVIRONMENTRELOADRESPONSE']._serialized_end=4682
  _globals['_FUNCTIONENVIRONMENTRELOADRESPONSE_CAPABILITIESENTRY']._serialized_start=2644
  _globals['_FUNCTIONENVIRONMENTRELOADRESPONSE_CAPABILITIESENTRY']._serialized_end=2695
  _globals['_CLOSESHAREDMEMORYRESOURCESREQUEST']._serialized_start=4684
  _globals['_CLOSESHAREDMEMORYRESOURCESREQUEST']._serialized_end=4738
  _globals['_CLOSESHAREDMEMORYRESOURCESRESPONSE']._serialized_start=4741
  _globals['_CLOSESHAREDMEMORYRESOURCESRESPONSE']._serialized_end=4944
  _globals['_CLOSESHAREDMEMORYRESOURCESRESPONSE_CLOSEMAPRESULTSENTRY']._serialized_start=4890
  _globals['_CLOSESHAREDMEMORYRESOURCESRESPONSE_CLOSEMAPRESULTSENTRY']._serialized_end=4944
  _globals['_FUNCTIONLOADREQUESTCOLLECTION']._serialized_start=4946
  _globals['_FUNCTIONLOADREQUESTCOLLECTION']._serialized_end=5057
  _globals['_FUNCTIONLOADRESPONSECOLLECTION']._serialized_start=5059
  _globals['_FUNCTIONLOADRESPONSECOLLECTION']._serialized_end=5173
  _globals['_FUNCTIONLOADREQUEST']._serialized_start=5176
  _globals['_FUNCTIONLOADREQUEST']._serialized_end=5320
  _globals['_FUNCTIONLOADRESPONSE']._serialized_start=5323
  _globals['_FUNCTIONLOADRESPONSE']._serialized_end=5457
  _globals['_RPCFUNCTIONMETADATA']._serialized_start=5460
  _globals['_RPCFUNCTIONMETADATA']._serialized_end=6099
  _globals['_RPCFUNCTIONMETADATA_BINDINGSENTRY']._serialized_start=5961
  _globals['_RPCFUNCTIONMETADATA_BINDINGSENTRY']._serialized_end=6048
  _globals['_RPCFUNCTIONMETADATA_PROPERTIESENTRY']._serialized_start=6050
  _globals['_RPCFUNCTIONMETADATA_PROPERTIESENTRY']._serialized_end=6099
  _globals['_FUNCTIONSMETADATAREQUEST']._serialized_start=6101
  _globals['_FUNCTIONSMETADATAREQUEST']._serialized_end=6159
  _globals['_FUNCTIONMETADATARESPONSE']._serialized_start=6162
  _globals['_FUNCTIONMETADATARESPONSE']._serialized_end=6367
  _globals['_INVOCATIONREQUEST']._serialized_start=6370
  _globals['_INVOCATIONREQUEST']._serialized_end=6816
  _globals['_INVOCATIONREQUEST_TRIGGERMETADATAENTRY']._serialized_start=6724
  _globals['_INVOCATIONREQUEST_TRIGGERMETADATAENTRY']._serialized_end=6816
  _globals['_RPCTRACECONTEXT']._serialized_start=6819
  _globals['_RPCTRACECONTEXT']._serialized_end=7010
  _globals['_RPCTRACECONTEXT_ATTRIBUTESENTRY']._serialized_start=6961
  _globals['_RPCTRACECONTEXT_ATTRIBUTESENTRY']._serialized_end=7010
  _globals['_RETRYCONTEXT']._serialized_start=7012
  _globals['_RETRYCONTEXT']._serialized_end=7132
  _globals['_INVOCATIONCANCEL']._serialized_start=7134
  _globals['_INVOCATIONCANCEL']._serialized_end=7224
  _globals['_INVOCATIONRESPONSE']._serialized_start=7227
  _globals['_INVOCATIONRESPONSE']._serialized_end=7453
  _globals['_WORKERWARMUPREQUEST']._serialized_start=7455
  _globals['_WORKERWARMUPREQUEST']._serialized_end=7502
  _globals['_WORKERWARMUPRESPONSE']._serialized_start=7504
  _globals['_WORKERWARMUPRESPONSE']._serialized_end=7583
  _globals['_TYPEDDATA']._serialized_start=7586
  _globals['_TYPEDDATA']._serialized_end=8224
  _globals['_RPCSHAREDMEMORY']._serialized_start=8226
  _globals['_RPCSHAREDMEMORY']._serialized_end=8342
  _globals['_COLLECTIONSTRING']._serialized_start=8344
  _globals['_COLLECTIONSTRING']._serialized_end=8378
  _globals['_COLLECTIONBYTES']._serialized_start=8380
  _globals['_COLLECTIONBYTES']._serialized_end=8412
  _globals['_COLLECTIONDOUBLE']._serialized_start=8414
  _globals['_COLLECTIONDOUBLE']._serialized_end=8448
  _globals['_COLLECTIONSINT64']._serialized_start=8450
  _globals['_COLLECTIONSINT64']._serialized_end=8484
  _globals['_PARAMETERBINDING']._serialized_start=8487
  _globals['_PARAMETERBINDING']._serialized_end=8658
  _globals['_BINDINGINFO']._serialized_start=8661
  _globals['_BINDINGINFO']._serialized_end=9056
  _globals['_BINDINGINFO_PROPERTIESENTRY']._serialized_start=6050
  _globals['_BINDINGINFO_PROPERTIESENTRY']._serialized_end=6099
  _globals['_BINDINGINFO_DIRECTION']._serialized_start=8954
  _globals['_BINDINGINFO_DIRECTION']._serialized_end=8993
  _globals['_BINDINGINFO_DATATYPE']._serialized_start=8995
  _globals['_BINDINGINFO_DATATYPE']._serialized_end=9056
  _globals['_RPCLOG']._serialized_start=9059
  _globals['_RPCLOG']._serialized_end=9674
  _globals['_RPCLOG_PROPERTIESMAPENTRY']._serialized_start=9430
  _globals['_RPCLOG_PROPERTIESMAPENTRY']._serialized_end=9520
  _globals['_RPCLOG_LEVEL']._serialized_start=9522
  _globals['_RPCLOG_LEVEL']._serialized_end=9616
  _globals['_RPCLOG_RPCLOGCATEGORY']._serialized_start=9618
  _globals['_RPCLOG_RPCLOGCATEGORY']._serialized_end=9674
  _globals['_RPCEXCEPTION']._serialized_start=9676
  _globals['_RPCEXCEPTION']._serialized_end=9785
  _globals['_RPCHTTPCOOKIE']._serialized_start=9788
  _globals['_RPCHTTPCOOKIE']._serialized_end=10163
  _globals['_RPCHTTPCOOKIE_SAMESITE']._serialized_start=10104
  _globals['_RPCHTTPCOOKIE_SAMESITE']._serialized_end=10163
  _globals['_RPCHTTP']._serialized_start=10166
  _globals['_RPCHTTP']._serialized_end=11259
  _globals['_RPCHTTP_HEADERSENTRY']._serialized_start=10904
  _globals['_RPCHTTP_HEADERSENTRY']._serialized_end=10950
  _globals['_RPCHTTP_PARAMSENTRY']._serialized_start=10952
  _globals['_RPCHTTP_PARAMSENTRY']._serialized_end=10997
  _globals['_RPCHTTP_QUERYENTRY']._serialized_start=10999
  _globals['_RPCHTTP_QUERYENTRY']._serialized_end=11043
  _globals['_RPCHTTP_NULLABLEHEADERSENTRY']._serialized_start=11045
  _globals['_RPCHTTP_NULLABLEHEADERSENTRY']._serialized_end=11116
  _globals['_RPCHTTP_NULLABLEPARAMSENTRY']._serialized_start=11118
  _globals['_RPCHTTP_NULLABLEPARAMSENTRY']._serialized_end=11188
  _globals['_RPCHTTP_NULLABLEQUERYENTRY']._serialized_start=11190
  _globals['_RPCHTTP_NULLABLEQUERYENTRY']._serialized_end=11259
  _globals['_MODELBINDINGDATA']._serialized_start=11261
  _globals['_MODELBINDINGDATA']._serialized_end=11351
  _globals['_COLLECTIONMODELBINDINGDATA']._serialized_start=11353
  _globals['_COLLECTIONMODELBINDINGDATA']._serialized_end=11454
  _globals['_RPCRETRYOPTIONS']._serialized_start=11457
  _globals['_RPCRETRYOPTIONS']._serialized_end=11797
  _globals['_RPCRETRYOPTIONS_RETRYSTRATEGY']._serialized_start=11740
  _globals['_RPCRETRYOPTIONS_RETRYSTRATEGY']._serialized_end=11797
  _globals['_FUNCTIONRPC']._serialized_start=11995
  _globals['_FUNCTIONRPC']._serialized_end=12119
# @@protoc_insertion_point(module_scope)
